<?php

namespace Drupal\layout_builder_section_variations\Controller;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;

/**
 * Provides a list builder for section variations.
 */
final class SectionVariationListBuilder extends ConfigEntityListBuilder {

  /**
   * Builds the header for the section variations list.
   *
   * @return array
   *   An associative array defining the table headers for section variations.
   */
  #[\Override] public function buildHeader(): array {
    $header['label'] = $this->t('Example');
    $header['id'] = $this->t('Machine name');

    return $header + parent::buildHeader();
  }

  /**
   * Builds a row for a section variation entity in the list.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The section variation entity being rendered in the list.
   *
   * @return array
   *   An associative array representing a single row in the table, where
   *   each key corresponds to a column.
   */
  #[\Override] public function buildRow(EntityInterface $entity): array {
    $row['label'] = $entity->label();
    $row['id'] = $entity->id();

    return $row + parent::buildRow($entity);
  }

}
